@@ -30,8 +30,6 @@ import signal
 from functools import wraps
 
 import txaio
-txaio.use_asyncio()  # noqa
-
 from autobahn.asyncio.websocket import WampWebSocketClientFactory
 from autobahn.asyncio.rawsocket import WampRawSocketClientFactory
 
@@ -356,14 +354,24 @@ def run(components, start_loop=True, log_level='info'):
     #   import signal
     #   signal.signal(signal.SIGINT, signal.SIG_DFL)
 
-    @asyncio.coroutine
-    def nicely_exit(signal):
+    async def nicely_exit(signal):
         log.info("Shutting down due to {signal}", signal=signal)
 
-        tasks = asyncio.Task.all_tasks()
+        try:
+            tasks = asyncio.Task.all_tasks()
+        except AttributeError:
+            # this changed with python >= 3.7
+            tasks = asyncio.all_tasks()
+
         for task in tasks:
             # Do not cancel the current task.
-            if task is not asyncio.Task.current_task():
+
+            try:
+                current_task = asyncio.Task.current_task()
+            except AttributeError:
+                current_task = asyncio.current_task()
+
+            if task is not current_task:
                 task.cancel()
 
         def cancel_all_callback(fut):
